
/* Generated data (by glib-mkenums) */

#ifndef __SHELL_ENUM_TYPES_H__
#define __SHELL_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "shell-app.h" */
GType shell_app_state_get_type (void) G_GNUC_CONST;
#define SHELL_TYPE_APP_STATE (shell_app_state_get_type())

/* enumerations from "shell-global.h" */
GType shell_cursor_get_type (void) G_GNUC_CONST;
#define SHELL_TYPE_CURSOR (shell_cursor_get_type())

GType shell_stage_input_mode_get_type (void) G_GNUC_CONST;
#define SHELL_TYPE_STAGE_INPUT_MODE (shell_stage_input_mode_get_type())

G_END_DECLS

#endif /* !__SHELL_ENUM_TYPES_H__ */

/* Generated data ends here */

